FirebaseBackupProvider class

Firebase Storage backup provider.

Stores encrypted backup files under backups/{uid}/ in Firebase Cloud Storage. Requires an authenticated Firebase user.

Files are stored at: backups/{uid}/{subfolder}/{fileName}

Constructors

FirebaseBackupProvider({FirebaseStorage? storage, FirebaseAuth? auth, String subfolder = 'local_first_backups'})
Creates a FirebaseBackupProvider.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
subfolder String
Subdirectory within the user's backup folder.
final

Methods

delete(BackupMetadata metadata) Future<void>
Deletes a backup from cloud storage.
download(BackupMetadata metadata) Future<List<int>>
Downloads backup bytes from cloud storage.
listBackups() Future<List<BackupMetadata>>
Lists available backups, newest first.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
upload({required String fileName, required List<int> data}) Future<BackupMetadata>
Uploads encrypted backup bytes to cloud storage.

Operators

operator ==(Object other) bool
The equality operator.
inherited